starcluster.webtools.StoppableHttpServer

Package starcluster :: Module webtools :: Class StoppableHttpServer |
[hide private]
[frames] | no frames]

# Class StoppableHttpServer

source code

http server that reacts to self.stop flag

Instance Methods | [hide private]
serve_forever(self) Handle one request at a time until stopped. | source code
Inherited from `BaseHTTPServer.HTTPServer`: `server_bind` Inherited from `SocketServer.TCPServer`: `__init__`, `close_request`, `fileno`, `get_request`, `server_activate`, `server_close` Inherited from `SocketServer.BaseServer`: `finish_request`, `handle_error`, `handle_request`, `handle_timeout`, `process_request`, `shutdown`, `verify_request` Inherited from `SocketServer.BaseServer` (private): `_handle_request_noblock`

Class Variables | [hide private]
Inherited from `BaseHTTPServer.HTTPServer`: `allow_reuse_address` Inherited from `SocketServer.TCPServer`: `address_family`, `request_queue_size`, `socket_type` Inherited from `SocketServer.BaseServer`: `timeout`

Method Details | [hide private]

### serve_forever(self) | source code
Handle one request at a time until stopped. Overrides: SocketServer.BaseServer.serve_forever